@@ -6,17 +6,20 @@
  *
  * Copyright (c) 1991-1994 The Regents of the University of California.
  * Copyright (c) 1994-1997 Sun Microsystems, Inc.
- * Copyright 2001, Apple Computer, Inc.
+ * Copyright 2001-2009, Apple Inc.
+ * Copyright (c) 2006-2009 Daniel A. Steffen <das@users.sourceforge.net>
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tkMacOSXDefault.h,v 1.2 2002/08/31 06:12:29 das Exp $
  */
 
 #ifndef _TKMACDEFAULT
 #define _TKMACDEFAULT
 
+//#ifndef TK_MAC_BUTTON_USE_COMPATIBILITY_METRICS
+//#define TK_MAC_BUTTON_USE_COMPATIBILITY_METRICS 1
+//#endif
+
 /*
  * The definitions below provide symbolic names for the default colors.
  * NORMAL_BG -		Normal background color.
@@ -28,28 +31,29 @@
  * DISABLED -		Foreground color when widget is disabled.
  */
 
-#define BLACK		"Black"
-#define WHITE		"White"
-
-#define NORMAL_BG	"systemWindowBody"
-#define ACTIVE_BG	"#ececec"
-#define SELECT_BG	"systemHighlight"
-#define SELECT_FG	"systemHighlightText"
-#define TROUGH		"#c3c3c3"
-#define INDICATOR	"#b03060"
-#define DISABLED	"#a3a3a3"
+#define BLACK			"Black"
+#define WHITE			"White"
+#define NORMAL_BG		"systemWindowBody"
+#define ACTIVE_BG		"systemButtonFacePressed"
+#define ACTIVE_FG		"systemPushButtonPressedText"
+#define SELECT_BG		"systemHighlight"
+#define SELECT_FG		None
+#define INACTIVE_SELECT_BG	"systemHighlightSecondary"
+#define TROUGH			"#c3c3c3"
+#define INDICATOR		"#b03060"
+#define DISABLED		"#a3a3a3"
 
 /*
  * Defaults for labels, buttons, checkbuttons, and radiobuttons:
  */
 
 #define DEF_BUTTON_ANCHOR		"center"
-#define DEF_BUTTON_ACTIVE_BG_COLOR	"systemButtonText"
+#define DEF_BUTTON_ACTIVE_BG_COLOR	ACTIVE_BG
 #define DEF_BUTTON_ACTIVE_BG_MONO	BLACK
-#define DEF_BUTTON_ACTIVE_FG_COLOR	"systemButtonFace"
+#define DEF_BUTTON_ACTIVE_FG_COLOR	ACTIVE_FG
 #define DEF_CHKRAD_ACTIVE_FG_COLOR	DEF_BUTTON_ACTIVE_FG_COLOR
 #define DEF_BUTTON_ACTIVE_FG_MONO	WHITE
-//IGR#define DEF_BUTTON_BG_COLOR		"systemButtonFace"
+/* #define DEF_BUTTON_BG_COLOR	"systemButtonFace"*/
 #define DEF_BUTTON_BG_COLOR		WHITE
 #define DEF_BUTTON_BG_MONO		WHITE
 #define DEF_BUTTON_BITMAP		""
@@ -60,25 +64,40 @@
 #define DEF_BUTTON_DEFAULT		"disabled"
 #define DEF_BUTTON_DISABLED_FG_COLOR	DISABLED
 #define DEF_BUTTON_DISABLED_FG_MONO	""
-//IGR#define DEF_BUTTON_FG			"systemButtonText"
-#define DEF_BUTTON_FG			BLACK
+#define DEF_BUTTON_FG			"systemButtonText"
 #define DEF_CHKRAD_FG			DEF_BUTTON_FG
-#define DEF_BUTTON_FONT			"system"
+#define DEF_BUTTON_FONT			"TkDefaultFont"
 #define DEF_BUTTON_HEIGHT		"0"
 #define DEF_BUTTON_HIGHLIGHT_BG_COLOR	DEF_BUTTON_BG_COLOR
 #define DEF_BUTTON_HIGHLIGHT_BG_MONO	DEF_BUTTON_BG_MONO
 #define DEF_BUTTON_HIGHLIGHT		"systemButtonFrame"
 #define DEF_LABEL_HIGHLIGHT_WIDTH	"0"
-#define DEF_BUTTON_HIGHLIGHT_WIDTH	"4"
-#define DEF_BUTTON_IMAGE		(char *) NULL
+//#if TK_MAC_BUTTON_USE_COMPATIBILITY_METRICS
+//#define DEF_BUTTON_HIGHLIGHT_WIDTH	"4"
+//#define DEF_BUTTON_HIGHLIGHT_WIDTH_NOCM	"1"
+//#else
+#define DEF_BUTTON_HIGHLIGHT_WIDTH	"1"
+//#endif
+#define DEF_BUTTON_IMAGE		((char *) NULL)
 #define DEF_BUTTON_INDICATOR		"1"
 #define DEF_BUTTON_JUSTIFY		"center"
 #define DEF_BUTTON_OFF_VALUE		"0"
 #define DEF_BUTTON_ON_VALUE		"1"
+#define DEF_BUTTON_TRISTATE_VALUE	""
 #define DEF_BUTTON_OVER_RELIEF		""
-#define DEF_BUTTON_PADX			"12"
+//#if TK_MAC_BUTTON_USE_COMPATIBILITY_METRICS
+//#define DEF_BUTTON_PADX			"12"
+//#define DEF_BUTTON_PADX_NOCM		"1"
+//#else
+#define DEF_BUTTON_PADX			"1"
+//#endif
 #define DEF_LABCHKRAD_PADX		"1"
-#define DEF_BUTTON_PADY			"3"
+//#if TK_MAC_BUTTON_USE_COMPATIBILITY_METRICS
+//#define DEF_BUTTON_PADY			"3"
+//#define DEF_BUTTON_PADY_NOCM		"1"
+//#else
+#define DEF_BUTTON_PADY			"1"
+//#endif
 #define DEF_LABCHKRAD_PADY		"1"
 #define DEF_BUTTON_RELIEF		"flat"
 #define DEF_LABCHKRAD_RELIEF		"flat"
@@ -86,10 +105,10 @@
 #define DEF_BUTTON_REPEAT_INTERVAL	"0"
 #define DEF_BUTTON_SELECT_COLOR		INDICATOR
 #define DEF_BUTTON_SELECT_MONO		BLACK
-#define DEF_BUTTON_SELECT_IMAGE		(char *) NULL
+#define DEF_BUTTON_SELECT_IMAGE		((char *) NULL)
 #define DEF_BUTTON_STATE		"normal"
 #define DEF_LABEL_TAKE_FOCUS		"0"
-#define DEF_BUTTON_TAKE_FOCUS		(char *) NULL
+#define DEF_BUTTON_TAKE_FOCUS		((char *) NULL)
 #define DEF_BUTTON_TEXT			""
 #define DEF_BUTTON_TEXT_VARIABLE	""
 #define DEF_BUTTON_UNDERLINE		"-1"
@@ -125,9 +144,9 @@
 #define DEF_CANVAS_SELECT_MONO		BLACK
 #define DEF_CANVAS_SELECT_BD_COLOR	"1"
 #define DEF_CANVAS_SELECT_BD_MONO	"0"
-#define DEF_CANVAS_SELECT_FG_COLOR	BLACK
+#define DEF_CANVAS_SELECT_FG_COLOR	SELECT_FG
 #define DEF_CANVAS_SELECT_FG_MONO	WHITE
-#define DEF_CANVAS_TAKE_FOCUS		(char *) NULL
+#define DEF_CANVAS_TAKE_FOCUS		((char *) NULL)
 #define DEF_CANVAS_WIDTH		"10c"
 #define DEF_CANVAS_X_SCROLL_CMD		""
 #define DEF_CANVAS_X_SCROLL_INCREMENT	"0"
@@ -138,21 +157,32 @@
  * Defaults for entries:
  */
 
+/*
+ * I test the following two values in TkpDrawEntryBorderAndFocus
+ * to determine whether to use the native entry widget. So if
+ * you change the defaults to be different from these, then you
+ * won't get the native widget by default.
+ */
+
+#define MAC_OSX_FOCUS_WIDTH		3
+#define MAC_OSX_ENTRY_BORDER		2
+#define MAC_OSX_ENTRY_RELIEF		TK_RELIEF_SUNKEN
+#define MAC_OSX_ENTRY_SELECT_RELIEF	TK_RELIEF_FLAT
+
 #define DEF_ENTRY_BG_COLOR		NORMAL_BG
 #define DEF_ENTRY_BG_MONO		WHITE
-/* #define DEF_ENTRY_BORDER_WIDTH		"2" */
-#define DEF_ENTRY_BORDER_WIDTH		"1"
+#define DEF_ENTRY_BORDER_WIDTH		"2"
 #define DEF_ENTRY_CURSOR		"xterm"
 #define DEF_ENTRY_DISABLED_BG_COLOR	NORMAL_BG
 #define DEF_ENTRY_DISABLED_BG_MONO	WHITE
 #define DEF_ENTRY_DISABLED_FG		DISABLED
 #define DEF_ENTRY_EXPORT_SELECTION	"1"
-#define DEF_ENTRY_FONT			"Helvetica 12"
+#define DEF_ENTRY_FONT			"TkTextFont"
 #define DEF_ENTRY_FG			BLACK
 #define DEF_ENTRY_HIGHLIGHT_BG		NORMAL_BG
 #define DEF_ENTRY_HIGHLIGHT		BLACK
 /* #define DEF_ENTRY_HIGHLIGHT_WIDTH	"3" */
-#define DEF_ENTRY_HIGHLIGHT_WIDTH	"0"
+#define DEF_ENTRY_HIGHLIGHT_WIDTH	"3"
 #define DEF_ENTRY_INSERT_BG		BLACK
 #define DEF_ENTRY_INSERT_BD_COLOR	"0"
 #define DEF_ENTRY_INSERT_BD_MONO	"0"
@@ -163,8 +193,8 @@
 #define DEF_ENTRY_JUSTIFY		"left"
 #define DEF_ENTRY_READONLY_BG_COLOR	NORMAL_BG
 #define DEF_ENTRY_READONLY_BG_MONO	WHITE
-/* #define DEF_ENTRY_RELIEF		"sunken" */
-#define DEF_ENTRY_RELIEF		"solid"
+#define DEF_ENTRY_RELIEF		"sunken"
+/* #define DEF_ENTRY_RELIEF		"solid" */
 #define DEF_ENTRY_SCROLL_COMMAND	""
 #define DEF_ENTRY_SELECT_COLOR		SELECT_BG
 #define DEF_ENTRY_SELECT_MONO		BLACK
@@ -172,9 +202,9 @@
 #define DEF_ENTRY_SELECT_BD_MONO	"0"
 #define DEF_ENTRY_SELECT_FG_COLOR	SELECT_FG
 #define DEF_ENTRY_SELECT_FG_MONO	WHITE
-#define DEF_ENTRY_SHOW			(char *) NULL
+#define DEF_ENTRY_SHOW			((char *) NULL)
 #define DEF_ENTRY_STATE			"normal"
-#define DEF_ENTRY_TAKE_FOCUS		(char *) NULL
+#define DEF_ENTRY_TAKE_FOCUS		((char *) NULL)
 #define DEF_ENTRY_TEXT_VARIABLE		""
 #define DEF_ENTRY_WIDTH			"20"
 
@@ -208,7 +238,7 @@
 #define DEF_LABELFRAME_CLASS		"Labelframe"
 #define DEF_LABELFRAME_RELIEF		"groove"
 #define DEF_LABELFRAME_FG		"systemButtonText"
-#define DEF_LABELFRAME_FONT		"system"
+#define DEF_LABELFRAME_FONT		"TkDefaultFont"
 #define DEF_LABELFRAME_TEXT		""
 #define DEF_LABELFRAME_LABELANCHOR	"nw"
 
@@ -216,14 +246,14 @@
  * Defaults for listboxes:
  */
 
-#define DEF_LISTBOX_ACTIVE_STYLE	"underline"
-#define DEF_LISTBOX_BG_COLOR		NORMAL_BG
+#define DEF_LISTBOX_ACTIVE_STYLE	"dotbox"
+#define DEF_LISTBOX_BG_COLOR		WHITE
 #define DEF_LISTBOX_BG_MONO		WHITE
 #define DEF_LISTBOX_BORDER_WIDTH	"1"
 #define DEF_LISTBOX_CURSOR		""
 #define DEF_LISTBOX_DISABLED_FG		DISABLED
 #define DEF_LISTBOX_EXPORT_SELECTION	"1"
-#define DEF_LISTBOX_FONT		"application"
+#define DEF_LISTBOX_FONT		"TkTextFont"
 #define DEF_LISTBOX_FG			BLACK
 #define DEF_LISTBOX_HEIGHT		"10"
 #define DEF_LISTBOX_HIGHLIGHT_BG	NORMAL_BG
@@ -240,62 +270,67 @@
 #define DEF_LISTBOX_SELECT_MODE		"browse"
 #define DEF_LISTBOX_SET_GRID		"0"
 #define DEF_LISTBOX_STATE		"normal"
-#define DEF_LISTBOX_TAKE_FOCUS		(char *) NULL
+#define DEF_LISTBOX_TAKE_FOCUS		((char *) NULL)
 #define DEF_LISTBOX_WIDTH		"20"
 
 /*
  * Defaults for individual entries of menus:
  */
 
-#define DEF_MENU_ENTRY_ACTIVE_BG	(char *) NULL
-#define DEF_MENU_ENTRY_ACTIVE_FG	(char *) NULL
-#define DEF_MENU_ENTRY_ACCELERATOR	(char *) NULL
-#define DEF_MENU_ENTRY_BG		(char *) NULL
+#define DEF_MENU_ENTRY_ACTIVE_BG	((char *) NULL)
+#define DEF_MENU_ENTRY_ACTIVE_FG	((char *) NULL)
+#define DEF_MENU_ENTRY_ACCELERATOR	((char *) NULL)
+#define DEF_MENU_ENTRY_BG		((char *) NULL)
 #define DEF_MENU_ENTRY_BITMAP		None
 #define DEF_MENU_ENTRY_COLUMN_BREAK	"0"
-#define DEF_MENU_ENTRY_COMMAND		(char *) NULL
+#define DEF_MENU_ENTRY_COMMAND		((char *) NULL)
 #define DEF_MENU_ENTRY_COMPOUND		"none"
-#define DEF_MENU_ENTRY_FG		(char *) NULL
-#define DEF_MENU_ENTRY_FONT		(char *) NULL
+#define DEF_MENU_ENTRY_FG		((char *) NULL)
+#define DEF_MENU_ENTRY_FONT		((char *) NULL)
 #define DEF_MENU_ENTRY_HIDE_MARGIN	"0"
-#define DEF_MENU_ENTRY_IMAGE		(char *) NULL
+#define DEF_MENU_ENTRY_IMAGE		((char *) NULL)
 #define DEF_MENU_ENTRY_INDICATOR	"1"
-#define DEF_MENU_ENTRY_LABEL		(char *) NULL
-#define DEF_MENU_ENTRY_MENU		(char *) NULL
+#define DEF_MENU_ENTRY_LABEL		((char *) NULL)
+#define DEF_MENU_ENTRY_MENU		((char *) NULL)
 #define DEF_MENU_ENTRY_OFF_VALUE	"0"
 #define DEF_MENU_ENTRY_ON_VALUE		"1"
-#define DEF_MENU_ENTRY_SELECT_IMAGE	(char *) NULL
+#define DEF_MENU_ENTRY_SELECT_IMAGE	((char *) NULL)
 #define DEF_MENU_ENTRY_STATE		"normal"
-#define DEF_MENU_ENTRY_VALUE		(char *) NULL
-#define DEF_MENU_ENTRY_CHECK_VARIABLE	(char *) NULL
+#define DEF_MENU_ENTRY_VALUE		((char *) NULL)
+#define DEF_MENU_ENTRY_CHECK_VARIABLE	((char *) NULL)
 #define DEF_MENU_ENTRY_RADIO_VARIABLE	"selectedButton"
-#define DEF_MENU_ENTRY_SELECT	(char *) NULL
+#define DEF_MENU_ENTRY_SELECT		((char *) NULL)
 #define DEF_MENU_ENTRY_UNDERLINE	"-1"
 
 /*
  * Defaults for menus overall:
  */
 
-#define DEF_MENU_ACTIVE_BG_COLOR	"SystemMenuActive"
+#define DEF_MENU_ACTIVE_BG_COLOR	"systemMenuActive"
 #define DEF_MENU_ACTIVE_BG_MONO		BLACK
 #define DEF_MENU_ACTIVE_BORDER_WIDTH	"0"
-#define DEF_MENU_ACTIVE_FG_COLOR	"SystemMenuActiveText"
+#define DEF_MENU_ACTIVE_FG_COLOR	"systemMenuActiveText"
 #define DEF_MENU_ACTIVE_FG_MONO		WHITE
-#define DEF_MENU_BG_COLOR		"SystemMenu"
+#define DEF_MENU_BG_COLOR		"systemMenu"
 #define DEF_MENU_BG_MONO		WHITE
 #define DEF_MENU_BORDER_WIDTH		"0"
 #define DEF_MENU_CURSOR			"arrow"
-#define DEF_MENU_DISABLED_FG_COLOR	"SystemMenuDisabled"
+#define DEF_MENU_DISABLED_FG_COLOR	"systemMenuDisabled"
 #define DEF_MENU_DISABLED_FG_MONO	""
-#define DEF_MENU_FONT			"system"
-#define DEF_MENU_FG			"SystemMenuText"
+#define DEF_MENU_FONT			"menu" /* special: see tkMacOSXMenu.c */
+#define DEF_MENU_FG			"systemMenuText"
 #define DEF_MENU_POST_COMMAND		""
 #define DEF_MENU_RELIEF			"flat"
-#define DEF_MENU_SELECT_COLOR		"SystemMenuActive"
+#define DEF_MENU_SELECT_COLOR		"systemMenuActive"
 #define DEF_MENU_SELECT_MONO		BLACK
 #define DEF_MENU_TAKE_FOCUS		"0"
-#define DEF_MENU_TEAROFF		"1"
-#define DEF_MENU_TEAROFF_CMD		(char *) NULL
+
+/*
+ * FIXME: Turn the default back to 1 when we make tearoff menus work again.
+ */
+
+#define DEF_MENU_TEAROFF		"0"
+#define DEF_MENU_TEAROFF_CMD		((char *) NULL)
 #define DEF_MENU_TITLE			""
 #define DEF_MENU_TYPE			"normal"
 
@@ -306,7 +341,7 @@
 #define DEF_MENUBUTTON_ANCHOR		"center"
 #define DEF_MENUBUTTON_ACTIVE_BG_COLOR	ACTIVE_BG
 #define DEF_MENUBUTTON_ACTIVE_BG_MONO	BLACK
-#define DEF_MENUBUTTON_ACTIVE_FG_COLOR	BLACK
+#define DEF_MENUBUTTON_ACTIVE_FG_COLOR	ACTIVE_FG
 #define DEF_MENUBUTTON_ACTIVE_FG_MONO	WHITE
 #define DEF_MENUBUTTON_BG_COLOR		NORMAL_BG
 #define DEF_MENUBUTTON_BG_MONO		WHITE
@@ -316,20 +351,19 @@
 #define DEF_MENUBUTTON_DIRECTION	"below"
 #define DEF_MENUBUTTON_DISABLED_FG_COLOR DISABLED
 #define DEF_MENUBUTTON_DISABLED_FG_MONO	""
-#define DEF_MENUBUTTON_FONT		"system"
+#define DEF_MENUBUTTON_FONT		"TkDefaultFont"
 #define DEF_MENUBUTTON_FG		BLACK
 #define DEF_MENUBUTTON_HEIGHT		"0"
 #define DEF_MENUBUTTON_HIGHLIGHT_BG_COLOR DEF_MENUBUTTON_BG_COLOR
 #define DEF_MENUBUTTON_HIGHLIGHT_BG_MONO  DEF_MENUBUTTON_BG_MONO
 #define DEF_MENUBUTTON_HIGHLIGHT	BLACK
 #define DEF_MENUBUTTON_HIGHLIGHT_WIDTH	"0"
-#define DEF_MENUBUTTON_IMAGE		(char *) NULL
-#define DEF_MENUBUTTON_INDICATOR	"0"
-/* #define DEF_MENUBUTTON_JUSTIFY		"center" */
+#define DEF_MENUBUTTON_IMAGE		((char *) NULL)
+#define DEF_MENUBUTTON_INDICATOR	"1"
 #define DEF_MENUBUTTON_JUSTIFY		"left"
 #define DEF_MENUBUTTON_MENU		""
-#define DEF_MENUBUTTON_PADX		"4p"
-#define DEF_MENUBUTTON_PADY		"3p"
+#define DEF_MENUBUTTON_PADX		"4"
+#define DEF_MENUBUTTON_PADY		"3"
 #define DEF_MENUBUTTON_RELIEF		"flat"
 #define DEF_MENUBUTTON_STATE		"normal"
 #define DEF_MENUBUTTON_TAKE_FOCUS	"0"
@@ -347,10 +381,10 @@
 #define DEF_MESSAGE_ASPECT		"150"
 #define DEF_MESSAGE_BG_COLOR		NORMAL_BG
 #define DEF_MESSAGE_BG_MONO		WHITE
-#define DEF_MESSAGE_BORDER_WIDTH	"2"
+#define DEF_MESSAGE_BORDER_WIDTH	"1"
 #define DEF_MESSAGE_CURSOR		""
 #define DEF_MESSAGE_FG			BLACK
-#define DEF_MESSAGE_FONT		"system"
+#define DEF_MESSAGE_FONT		"TkDefaultFont"
 #define DEF_MESSAGE_HIGHLIGHT_BG	NORMAL_BG
 #define DEF_MESSAGE_HIGHLIGHT		BLACK
 #define DEF_MESSAGE_HIGHLIGHT_WIDTH	"0"
@@ -368,19 +402,19 @@
 
 #define DEF_PANEDWINDOW_BG_COLOR	NORMAL_BG
 #define DEF_PANEDWINDOW_BG_MONO		WHITE
-#define DEF_PANEDWINDOW_BORDERWIDTH	"2"
+#define DEF_PANEDWINDOW_BORDERWIDTH	"1"
 #define DEF_PANEDWINDOW_CURSOR		""
 #define DEF_PANEDWINDOW_HANDLEPAD	"8"
 #define DEF_PANEDWINDOW_HANDLESIZE	"8"
 #define DEF_PANEDWINDOW_HEIGHT		""
-#define DEF_PANEDWINDOW_OPAQUERESIZE	"0"
+#define DEF_PANEDWINDOW_OPAQUERESIZE	"1"
 #define DEF_PANEDWINDOW_ORIENT		"horizontal"
 #define DEF_PANEDWINDOW_RELIEF		"flat"
 #define DEF_PANEDWINDOW_SASHCURSOR	""
-#define DEF_PANEDWINDOW_SASHPAD		"2"
-#define DEF_PANEDWINDOW_SASHRELIEF	"raised"
-#define DEF_PANEDWINDOW_SASHWIDTH	"2"
-#define DEF_PANEDWINDOW_SHOWHANDLE	"1"
+#define DEF_PANEDWINDOW_SASHPAD		"0"
+#define DEF_PANEDWINDOW_SASHRELIEF	"flat"
+#define DEF_PANEDWINDOW_SASHWIDTH	"3"
+#define DEF_PANEDWINDOW_SHOWHANDLE	"0"
 #define DEF_PANEDWINDOW_WIDTH		""
 
 /*
@@ -395,6 +429,8 @@
 #define DEF_PANEDWINDOW_PANE_PADY	"0"
 #define DEF_PANEDWINDOW_PANE_STICKY	"nsew"
 #define DEF_PANEDWINDOW_PANE_WIDTH	""
+#define DEF_PANEDWINDOW_PANE_HIDE	"0"
+#define DEF_PANEDWINDOW_PANE_STRETCH	"last"
 
 /*
  * Defaults for scales:
@@ -405,11 +441,11 @@
 #define DEF_SCALE_BG_COLOR		NORMAL_BG
 #define DEF_SCALE_BG_MONO		WHITE
 #define DEF_SCALE_BIG_INCREMENT		"0"
-#define DEF_SCALE_BORDER_WIDTH		"2"
+#define DEF_SCALE_BORDER_WIDTH		"1"
 #define DEF_SCALE_COMMAND		""
 #define DEF_SCALE_CURSOR		""
 #define DEF_SCALE_DIGITS		"0"
-#define DEF_SCALE_FONT			"system"
+#define DEF_SCALE_FONT			"TkDefaultFont"
 #define DEF_SCALE_FG_COLOR		BLACK
 #define DEF_SCALE_FG_MONO		BLACK
 #define DEF_SCALE_FROM			"0"
@@ -430,7 +466,7 @@
 #define DEF_SCALE_SLIDER_LENGTH		"30"
 #define DEF_SCALE_SLIDER_RELIEF		"raised"
 #define DEF_SCALE_STATE			"normal"
-#define DEF_SCALE_TAKE_FOCUS		(char *) NULL
+#define DEF_SCALE_TAKE_FOCUS		((char *) NULL)
 #define DEF_SCALE_TICK_INTERVAL		"0"
 #define DEF_SCALE_TO			"100"
 #define DEF_SCALE_VARIABLE		""
@@ -445,26 +481,22 @@
 #define DEF_SCROLLBAR_ACTIVE_RELIEF	"raised"
 #define DEF_SCROLLBAR_BG_COLOR		NORMAL_BG
 #define DEF_SCROLLBAR_BG_MONO		WHITE
-/* #define DEF_SCROLLBAR_BORDER_WIDTH	"2" */
 #define DEF_SCROLLBAR_BORDER_WIDTH	"0"
 #define DEF_SCROLLBAR_COMMAND		""
 #define DEF_SCROLLBAR_CURSOR		""
 #define DEF_SCROLLBAR_EL_BORDER_WIDTH	"-1"
 #define DEF_SCROLLBAR_HIGHLIGHT_BG	NORMAL_BG
 #define DEF_SCROLLBAR_HIGHLIGHT		BLACK
-/* #define DEF_SCROLLBAR_HIGHLIGHT_WIDTH	"2" */
 #define DEF_SCROLLBAR_HIGHLIGHT_WIDTH	"0"
 #define DEF_SCROLLBAR_JUMP		"0"
 #define DEF_SCROLLBAR_ORIENT		"vertical"
-/*#define DEF_SCROLLBAR_RELIEF		"sunken" */
 #define DEF_SCROLLBAR_RELIEF		"flat"
 #define DEF_SCROLLBAR_REPEAT_DELAY	"300"
 #define DEF_SCROLLBAR_REPEAT_INTERVAL	"100"
-#define DEF_SCROLLBAR_TAKE_FOCUS	(char *) NULL
+#define DEF_SCROLLBAR_TAKE_FOCUS	((char *) NULL)
 #define DEF_SCROLLBAR_TROUGH_COLOR	TROUGH
 #define DEF_SCROLLBAR_TROUGH_MONO	WHITE
-/*#define DEF_SCROLLBAR_WIDTH		"15" */
-#define DEF_SCROLLBAR_WIDTH		"16"
+#define DEF_SCROLLBAR_WIDTH		"15"
 
 /*
  * Defaults for texts:
@@ -473,11 +505,12 @@
 #define DEF_TEXT_AUTO_SEPARATORS	"1"
 #define DEF_TEXT_BG_COLOR		NORMAL_BG
 #define DEF_TEXT_BG_MONO		WHITE
+#define DEF_TEXT_BLOCK_CURSOR		"0"
 #define DEF_TEXT_BORDER_WIDTH		"0"
 #define DEF_TEXT_CURSOR			"xterm"
 #define DEF_TEXT_FG			BLACK
 #define DEF_TEXT_EXPORT_SELECTION	"1"
-#define DEF_TEXT_FONT			"Courier 12"
+#define DEF_TEXT_FONT			"TkFixedFont"
 #define DEF_TEXT_HEIGHT			"24"
 #define DEF_TEXT_HIGHLIGHT_BG		NORMAL_BG
 #define DEF_TEXT_HIGHLIGHT		BLACK
@@ -488,25 +521,27 @@
 #define DEF_TEXT_INSERT_OFF_TIME	"300"
 #define DEF_TEXT_INSERT_ON_TIME		"600"
 #define DEF_TEXT_INSERT_WIDTH		"1"
-#define DEF_TEXT_MAX_UNDO    	"0"
+#define DEF_TEXT_MAX_UNDO		"0"
 #define DEF_TEXT_PADX			"1"
 #define DEF_TEXT_PADY			"1"
 #define DEF_TEXT_RELIEF			"flat"
+#define DEF_TEXT_INACTIVE_SELECT_COLOR	INACTIVE_SELECT_BG
 #define DEF_TEXT_SELECT_COLOR		SELECT_BG
 #define DEF_TEXT_SELECT_MONO		BLACK
 #define DEF_TEXT_SELECT_BD_COLOR	"1"
 #define DEF_TEXT_SELECT_BD_MONO		"0"
 #define DEF_TEXT_SELECT_FG_COLOR	SELECT_FG
 #define DEF_TEXT_SELECT_FG_MONO		WHITE
-#define DEF_TEXT_SELECT_RELIEF		"solid"
+#define DEF_TEXT_SELECT_RELIEF		"flat"
 #define DEF_TEXT_SET_GRID		"0"
 #define DEF_TEXT_SPACING1		"0"
 #define DEF_TEXT_SPACING2		"0"
 #define DEF_TEXT_SPACING3		"0"
 #define DEF_TEXT_STATE			"normal"
 #define DEF_TEXT_TABS			""
-#define DEF_TEXT_TAKE_FOCUS		(char *) NULL
-#define DEF_TEXT_UNDO    		"0"
+#define DEF_TEXT_TABSTYLE		"tabular"
+#define DEF_TEXT_TAKE_FOCUS		((char *) NULL)
+#define DEF_TEXT_UNDO			"0"
 #define DEF_TEXT_WIDTH			"80"
 #define DEF_TEXT_WRAP			"char"
 #define DEF_TEXT_XSCROLL_COMMAND	""
@@ -516,7 +551,7 @@
  * Defaults for canvas text:
  */
 
-#define DEF_CANVTEXT_FONT		"Helvetica 12"
+#define DEF_CANVTEXT_FONT		"TkDefaultFont"
 
 /*
  * Defaults for toplevels (most of the defaults for frames also apply
